@@ -170,10 +170,10 @@ SEIR <- function(u0,
 ##' summary(result)
 events_SEIR <- function() {
     data("events_SISe3", package = "SimInf", envir = environment())
-    events_SISe3$select[events_SISe3$event == "exit"] <- 2
-    events_SISe3$select[events_SISe3$event == "enter"] <- 1
+    events_SISe3$select[events_SISe3$event == "exit"] <- 2L
+    events_SISe3$select[events_SISe3$event == "enter"] <- 1L
     events_SISe3 <- events_SISe3[events_SISe3$event != "intTrans", ]
-    events_SISe3$select[events_SISe3$event == "extTrans"] <- 2
+    events_SISe3$select[events_SISe3$event == "extTrans"] <- 2L
     events_SISe3
 }
 
